/*
 * Copyright (c) 2021-2023 Datalayer, Inc.
 *
 * MIT License
 */
import { NotebookPanel } from '@jupyterlab/notebook';
import { CellSidebarWidget } from '../cell/sidebar';
import { CodeCell } from '@jupyterlab/cells';
// import { CodeMirrorEditor } from '@jupyterlab/codemirror';
// import { IInputPrompt } from '@jupyterlab/cells';
// import { NotebookInputPrompt } from './../cell/InputPrompt';
export const PYTHON_CELL_MIMETYPE = 'text/x-ipython';
export const SQL_CELL_MIMETYPE = 'application/sql';
export const isSQLCell = (cell) => {
    const datalayer = cell.model.getMetadata('datalayer');
    if (datalayer) {
        return (datalayer['sql'] === true);
    }
    return false;
};
class DatalayerCodeCell extends CodeCell {
    constructor(options) {
        super(options);
    }
}
/**
 * Extend the default implementation NotebookPanel.ContentFactory of `IContentFactory`.
 */
export class JupyterReactContentFactory extends NotebookPanel.ContentFactory {
    CellSidebar;
    notebookId;
    nbgrader;
    commands;
    constructor(notebookId, nbgrader, commands, options, CellSidebar) {
        super(options);
        this.CellSidebar = CellSidebar;
        this.notebookId = notebookId;
        this.nbgrader = nbgrader;
        this.commands = commands;
    }
    _updateSQLEditor = (cell) => {
        if (isSQLCell(cell)) {
            cell.editor.model.mimeType = SQL_CELL_MIMETYPE;
        }
    };
    _updateEditor = (cell) => {
        if (cell.editor) {
            cell.editor.model.mimeTypeChanged.connect((_, args) => {
                this._updateSQLEditor(cell);
            });
            this._updateSQLEditor(cell);
        }
    };
    /** @override */
    createNotebook(options) {
        const notebook = super.createNotebook(options);
        return notebook;
    }
    /** @override */
    createCellHeader() {
        if (this.CellSidebar) {
            return new CellSidebarWidget(this.CellSidebar, this.notebookId, this.nbgrader, this.commands);
        }
        return super.createCellHeader();
    }
    /** @override */
    createCodeCell(options) {
        const cell = new DatalayerCodeCell(options);
        if (cell.inViewport) {
            this._updateEditor(cell);
        }
        cell.displayChanged.connect(() => {
            this._updateEditor(cell);
        });
        cell.inViewportChanged.connect(() => {
            this._updateEditor(cell);
        });
        return cell;
    }
}
export default JupyterReactContentFactory;
//# sourceMappingURL=JupyterReactContentFactory.js.map