import { jsx as _jsx, jsxs as _jsxs, Fragment as _Fragment } from "react/jsx-runtime";
import { Box } from '@primer/react';
import { useEffect, useState } from 'react';
import { useJupyter } from '../../jupyter/JupyterContext';
import { newUuid } from '../../utils';
import { CodeMirrorDatalayerEditor } from '../codemirror';
import { Lumino } from '../lumino/Lumino';
import { KernelActionMenu, KernelProgressBar } from './../kernel';
import { OutputAdapter } from './OutputAdapter';
import { OutputRenderer } from './OutputRenderer';
import { useOutputsStore } from './OutputState';
import './Output.css';
export const Output = (props) => {
    const { defaultKernel } = useJupyter();
    const outputStore = useOutputsStore();
    const { adapter: propsAdapter, autoRun, clearTrigger, code, codePre, disableRun, executeTrigger, insertText, kernel: propsKernel, lumino, model, outputs: propsOutputs, receipt, showControl, showEditor, showKernelProgressBar = true, suppressCodeExecutionErrors = false, onExecutionPhaseChanged, id: sourceId, toolbarPosition, } = props;
    const kernel = propsKernel ?? defaultKernel;
    const [id, setId] = useState(sourceId);
    const [kernelStatus, setKernelStatus] = useState('unknown');
    const [outputs, setOutputs] = useState(propsOutputs);
    const [adapter, setAdapter] = useState();
    useEffect(() => {
        if (!id) {
            setId(newUuid());
        }
    }, []);
    useEffect(() => {
        const outputsCallback = (model, change) => {
            setOutputs(model.toJSON());
            if (id) {
                outputStore.setModel(id, model);
            }
        };
        const receiptCallback = (model, change) => {
            if (receipt && change.type === 'add') {
                change.newValues.map(val => {
                    if (val && val.data) {
                        const out = val.data['text/html']; // val.data['application/vnd.jupyter.stdout'];
                        if (out) {
                            if (out.indexOf(receipt) > -1) {
                                outputStore.setGradeSuccess(sourceId, true);
                            }
                        }
                    }
                });
            }
        };
        if (id && kernel) {
            const adapter = propsAdapter ?? new OutputAdapter(id, kernel, outputs ?? [], model, suppressCodeExecutionErrors);
            setAdapter(adapter);
            outputStore.setAdapter(id, adapter);
            if (model) {
                outputStore.setModel(id, model);
            }
            if (code) {
                outputStore.setInput(id, code);
            }
            adapter.outputArea.model.changed.connect(outputsCallback);
            if (receipt) {
                adapter.outputArea.model.changed.connect(receiptCallback);
            }
        }
        return () => {
            if (adapter) {
                adapter.outputArea.model.changed.disconnect(outputsCallback);
                adapter.outputArea.model.changed.disconnect(receiptCallback);
            }
        };
    }, [id, kernel]);
    useEffect(() => {
        if (adapter) {
            if (autoRun) {
                adapter.execute(code, onExecutionPhaseChanged);
            }
        }
    }, [adapter]);
    useEffect(() => {
        if (kernel) {
            kernel.ready.then(() => {
                setKernelStatus(kernel.connection.status);
                kernel.connection.statusChanged.connect((kernelConnection, status) => {
                    setKernelStatus(status);
                });
            });
            return () => {
                //        kernel.connection.then(k => k.shutdown().then(() => console.log(`Kernel ${k.id} is terminated.`)));
            };
        }
    }, [kernel]);
    const executeRequest = outputStore.getExecuteRequest(sourceId);
    useEffect(() => {
        if (adapter && executeRequest && executeRequest === id) {
            adapter.execute(code, onExecutionPhaseChanged);
        }
    }, [executeRequest, adapter]);
    useEffect(() => {
        if (adapter && executeTrigger > 0) {
            adapter.execute(code, onExecutionPhaseChanged);
        }
    }, [executeTrigger]);
    useEffect(() => {
        if (adapter && clearTrigger > 0) {
            adapter.clear();
        }
    }, [clearTrigger, adapter]);
    return (_jsxs(_Fragment, { children: [showEditor && adapter && id && (_jsx(Box, { sx: {
                    '& .cm-editor': {
                        borderRadius: '5px',
                    },
                }, children: _jsx(CodeMirrorDatalayerEditor, { autoRun: autoRun, code: code, codePre: codePre, disableRun: disableRun, insertText: insertText, kernel: kernel, outputAdapter: adapter, sourceId: id, toolbarPosition: toolbarPosition }) })), adapter && (_jsxs(Box, { display: "flex", children: [_jsx(Box, { flexGrow: 1, children: kernelStatus !== 'idle' && showKernelProgressBar && _jsx(KernelProgressBar, {}) }), showControl && (_jsx(Box, { style: { marginTop: '-13px' }, children: _jsx(KernelActionMenu, { kernel: kernel, outputAdapter: adapter }) }))] })), outputs && (_jsx(Box, { sx: {
                    '& .jp-OutputArea': {
                        fontSize: '10px',
                    },
                    '& .jp-OutputPrompt': {
                    //              display: 'none',
                    },
                    '& .jp-OutputArea-prompt': {
                        display: 'none',
                        //              width: '0px',
                    },
                    '& pre': {
                        fontSize: '12px',
                        wordBreak: 'break-all',
                        wordWrap: 'break-word',
                        whiteSpace: 'pre-wrap',
                    },
                }, children: lumino
                    ? adapter && _jsx(Lumino, { children: adapter.outputArea })
                    : outputs && (_jsx(_Fragment, { children: outputs.map((output) => {
                            return _jsx(OutputRenderer, { output: output });
                        }) })) }))] }));
};
Output.defaultProps = {
    autoRun: false,
    clearTrigger: 0,
    disableRun: false,
    executeTrigger: 0,
    showControl: true,
    lumino: true,
    outputs: [
        {
            output_type: 'execute_result',
            data: {
                'text/html': [
                    '<p>Type code in the cell and Shift+Enter to execute.</p>',
                ],
            },
            execution_count: 0,
            metadata: {},
        },
    ],
    notifyOnComplete: false,
    toolbarPosition: 'up',
};
export default Output;
//# sourceMappingURL=Output.js.map