import { jsx as _jsx, jsxs as _jsxs, Fragment as _Fragment } from "react/jsx-runtime";
/*
 * Copyright (c) 2021-2023 Datalayer, Inc.
 *
 * MIT License
 */
import { useState } from 'react';
import { createRoot } from 'react-dom/client';
import { Box, SegmentedControl, Label, Text } from '@primer/react';
import { ServiceManager } from '@jupyterlab/services';
import { createLiteServiceManager, createServerSettings, setJupyterServerUrl, getJupyterServerUrl, getJupyterServerToken, ServiceManagerLess, loadJupyterConfig, DEFAULT_JUPYTER_SERVER_URL, } from '../jupyter';
import { useJupyterReactStore } from '../state';
import { useNotebookStore, Notebook, SpinnerCentered } from './../components';
import { JupyterReactTheme } from '../theme';
import { createDatalayerServiceManager } from './../providers';
import nbformatExample from './notebooks/NotebookExample1.ipynb.json';
const NOTEBOOK_ID = 'notebook-mutations-id';
loadJupyterConfig();
const SERVICE_MANAGER_LESS = new ServiceManagerLess();
const NotebookMutationsKernel = () => {
    const [index, setIndex] = useState(0);
    const [nbformat, setNbformat] = useState(nbformatExample);
    const [readonly, setReadonly] = useState(true);
    const [serverless, setServerless] = useState(true);
    const [kernelIndex, setKernelIndex] = useState(-1);
    const [waiting, setWaiting] = useState(false);
    const [lite, setLite] = useState(false);
    const [serviceManager, setServiceManager] = useState(SERVICE_MANAGER_LESS);
    const [kernelConnections, setKernelConnections] = useState([]);
    const { datalayerConfig } = useJupyterReactStore();
    const notebookStore = useNotebookStore();
    const notebook = notebookStore.selectNotebook(NOTEBOOK_ID);
    const onKernelConnection = (kernelConnection) => {
        console.log('Received a Kernel Connection.', kernelConnection);
        if (kernelConnection) {
            setKernelConnections(kernelConnections.concat(kernelConnection));
        }
    };
    const changeIndex = (index) => {
        setIndex(index);
        switch (index) {
            case 0: {
                setKernelIndex(-1);
                setNbformat(notebook?.adapter?.notebookPanel?.content.model?.toJSON());
                setServerless(true);
                setReadonly(true);
                setLite(false);
                setServiceManager(SERVICE_MANAGER_LESS);
                break;
            }
            case 1: {
                setJupyterServerUrl(location.protocol + '//' + location.host);
                createLiteServiceManager().then(liteServiceManager => {
                    setKernelIndex(-1);
                    console.log('Lite Service Manager is available', liteServiceManager);
                    setServiceManager(liteServiceManager);
                    setNbformat(notebook?.adapter?.notebookPanel?.content.model?.toJSON());
                    setServerless(false);
                    setReadonly(false);
                    setLite(true);
                });
                break;
            }
            case 2: {
                setJupyterServerUrl(DEFAULT_JUPYTER_SERVER_URL);
                setKernelIndex(-1);
                setNbformat(notebook?.adapter?.notebookPanel?.content.model?.toJSON());
                setServerless(false);
                setReadonly(false);
                setLite(false);
                const serverSettings = createServerSettings(getJupyterServerUrl(), getJupyterServerToken());
                const serviceManager = new ServiceManager({ serverSettings });
                serviceManager['__NAME__'] = 'MutatingServiceManager';
                setServiceManager(serviceManager);
                break;
            }
            case 3: {
                //        setWaiting(true);
                setLite(false);
                createDatalayerServiceManager(datalayerConfig?.cpuEnvironment || 'python-simple-env', datalayerConfig?.credits || 1).then((serviceManager) => {
                    serviceManager['__NAME__'] = 'DatalayerCPUServiceManager';
                    setServiceManager(serviceManager);
                    setServerless(false);
                    setReadonly(false);
                    setKernelIndex(0);
                    setNbformat(notebook?.adapter?.notebookPanel?.content.model?.toJSON());
                    //          setWaiting(false);  
                });
                break;
            }
            case 4: {
                setWaiting(true);
                setLite(false);
                createDatalayerServiceManager(datalayerConfig?.gpuEnvironment || 'pytorch-cuda-env', datalayerConfig?.credits || 1).then((serviceManager) => {
                    setKernelIndex(0);
                    serviceManager['__NAME__'] = 'DatalayerGPUServiceManager';
                    setServiceManager(serviceManager);
                    setNbformat(notebook?.adapter?.notebookPanel?.content.model?.toJSON());
                    setServerless(false);
                    setReadonly(false);
                    setWaiting(false);
                });
                break;
            }
        }
    };
    return (_jsx(JupyterReactTheme, { children: _jsxs(_Fragment, { children: [_jsxs(Box, { display: "flex", children: [_jsx(Box, { children: _jsxs(SegmentedControl, { onChange: index => changeIndex(index), "aria-label": "jupyter-react-example", children: [_jsx(SegmentedControl.Button, { defaultSelected: index === 0, children: "Readonly" }), _jsx(SegmentedControl.Button, { defaultSelected: index === 1, children: "Browser Kernel" }), _jsx(SegmentedControl.Button, { defaultSelected: index === 2, children: "OSS Kernel (CPU)" }), _jsx(SegmentedControl.Button, { defaultSelected: index === 3, children: "Kernel (CPU)" }), _jsx(SegmentedControl.Button, { defaultSelected: index === 4, children: "Kernel (GPU)" })] }) }), _jsxs(Box, { ml: 1, mt: 1, children: [_jsxs(Label, { children: ["Lite: ", String(notebook?.adapter?.lite)] }), _jsxs(Label, { children: ["Service Manager URL: ", notebook?.adapter?.serviceManager.serverSettings.baseUrl] }), _jsxs(Label, { children: ["Service Manager is ready: ", String(notebook?.adapter?.serviceManager.isReady)] }), _jsxs(Label, { children: ["Kernel ID: ", notebook?.adapter?.kernel?.id] }), _jsxs(Label, { children: ["Kernel Banner: ", notebook?.adapter?.kernel?.info?.banner] })] })] }), _jsx(Box, { children: _jsx(Text, { as: "h3", children: "Kernel Connections" }) }), _jsx(Box, { children: kernelConnections.map(kernelConnection => {
                        return (_jsxs(Box, { children: ["Client ID (", kernelConnection.clientId, ") - Kernel ID (", kernelConnection.id, ") ", kernelConnection.name] }, kernelConnection.clientId));
                    }) }), waiting
                    ?
                        _jsx(SpinnerCentered, {})
                    :
                        _jsx(Notebook, { height: "calc(100vh - 2.6rem)", id: NOTEBOOK_ID, lite: lite, nbformat: nbformat, onKernelConnection: onKernelConnection, readonly: readonly, serverless: serverless, serviceManager: serviceManager, useRunningKernelIndex: kernelIndex })] }) }));
};
const div = document.createElement('div');
document.body.appendChild(div);
const root = createRoot(div);
root.render(_jsx(NotebookMutationsKernel, {}));
//# sourceMappingURL=NotebookMutationsKernel.js.map