/*
 * Copyright (c) 2021-2023 Datalayer, Inc.
 *
 * MIT License
 */
import { Widget } from '@lumino/widgets';
import { CellToolbar, DATALAYER_CELL_TOOLBAR_CLASS } from './CellToolbar';
export class CellToolbarWidget extends Widget {
    _panel;
    _props;
    constructor(panel, props) {
        super();
        this._panel = panel;
        this._props = props;
        this.updateConnectedCell = this.updateConnectedCell.bind(this);
        const cells = this._panel.context.model.cells;
        cells.changed.connect(this.updateConnectedCell);
        for (let i = 0; i < cells.length; ++i) {
            this._registerCellChanges(cells.get(i));
        }
    }
    updateConnectedCell(cells, changed) {
        changed.oldValues.forEach(this._deregisterCellChanges.bind(this));
        changed.newValues.forEach(this._registerCellChanges.bind(this));
    }
    _deregisterCellChanges(cellModel) {
    }
    _registerCellChanges(cellModel) {
        const disableHighlight = false;
        const codeCell = this._getCodeCell(cellModel);
        if (codeCell) {
            codeCell.displayChanged.connect(() => {
                this._updateCodeCell(codeCell, disableHighlight);
            });
            codeCell.inViewportChanged.connect(() => {
                this._updateCodeCell(codeCell, disableHighlight);
            });
            this._updateCodeCell(codeCell, disableHighlight);
        }
        else {
            if (cellModel.type === 'code') {
                console.error(`Could not find code cell for model: ${cellModel}`);
            }
        }
    }
    _getCodeCell(cellModel) {
        if (cellModel.type === 'code') {
            const cell = this._panel.content.widgets.find((widget) => widget.model === cellModel);
            return cell;
        }
        return null;
    }
    _updateCodeCell(cell, disableHighlight) {
        if (cell.inputArea) {
            const layout = cell.layout;
            if (layout) {
                const panelLayout = layout;
                if (!panelLayout.widgets[1].hasClass(DATALAYER_CELL_TOOLBAR_CLASS)) {
                    panelLayout.insertWidget(1, new CellToolbar(cell, this._props));
                }
            }
        }
    }
}
//# sourceMappingURL=CellToolbarWidget.js.map